==> pdfsam_4.0.1.orig.tar.xz: pdfsam-4.0.1/README.md <==
PDFsam (PDF Split And Merge)
==============================

Official SCM repository for PDFsam Basic, a free and open source, multi-platform software designed to extract pages, split, merge, mix and rotate PDF files.    
[![Build Status](https://travis-ci.org/torakiki/pdfsam.png)](https://travis-ci.org/torakiki/pdfsam)
[![License](http://img.shields.io/badge/license-AGPLv3-blue.svg)](http://www.gnu.org/licenses/agpl-3.0.html)
[![Join the chat at https://gitter.im/PDFsam/Lobby](https://badges.gitter.im/PDFsam/Lobby.svg)](https://gitter.im/PDFsam/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

Where
-------------------
Official website [pdfsam.org](https://pdfsam.org/ "PDFsam")

License
-------------------
PDFsam Basic is open source under the [GNU Affero General Public License] since version 3, previous versions are released under GPLv2.

Requirements
-------------------
PDFsam Basic is written using the JavaFX. Version 4 is released as a self-contained application and includes a jlinked OpenJDK 11 runtime while version 3 requires a Java Runtime Environment 8 with JavaFx installed in order to run.

Documentation
-------------------
Some [documentation](https://pdfsam.org/documentation/) and [FAQ](https://pdfsam.org/faq/)

Build
-------------------
This is a [simple guide](https://github.com/torakiki/pdfsam/wiki/Build-and-run) that can help you building PDFsam Basic

Contribute
------------------
Contributes are more then welcome, just please make sure you first read the [contributing guidelines](CONTRIBUTING.md)   

Translations
------------------
If you want to contribute translating PDFsam to your language you can do it [here](https://translations.launchpad.net/pdfsam/pdfsam-v3)

Tips and tweaks  
------------------
A list of properties and arguments that can tweak PDFsam behavior can be found [here](https://github.com/torakiki/pdfsam/wiki/Properties-and-arguments) 

  [GNU Affero General Public License]: http://www.gnu.org/licenses/agpl-3.0.html

==> pdfsam_4.3.4.orig.tar.xz: pdfsam-4.3.4/README.md <==
PDFsam (PDF Split And Merge)
==============================

Official SCM repository for PDFsam Basic, a free and open source, multi-platform software designed to extract pages, split, merge, mix and rotate PDF files.    
[![Build Status](https://travis-ci.org/torakiki/pdfsam.png)](https://travis-ci.org/torakiki/pdfsam)
[![License](http://img.shields.io/badge/license-AGPLv3-blue.svg)](http://www.gnu.org/licenses/agpl-3.0.html)
[![Join the chat at https://gitter.im/PDFsam/Lobby](https://badges.gitter.im/PDFsam/Lobby.svg)](https://gitter.im/PDFsam/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

Where
-------------------
Official website [pdfsam.org](https://pdfsam.org/ "PDFsam")

License
-------------------
PDFsam Basic is open source under the [GNU Affero General Public License] since version 3, previous versions are released under GPLv2.

Requirements
-------------------
PDFsam Basic is written using JavaFX. Version 4 is released as a self-contained application and includes a jlinked OpenJDK 11 runtime while version 3 requires a Java Runtime Environment 8 with JavaFx installed in order to run.

Documentation
-------------------
Some [documentation](https://pdfsam.org/documentation/) and [FAQ](https://pdfsam.org/faq/)

Build
-------------------
This is a [simple guide](https://github.com/torakiki/pdfsam/wiki/Build-and-run) that can help you building PDFsam Basic

Contribute
------------------
Contributes are more then welcome, just please make sure you first read the [contributing guidelines](CONTRIBUTING.md)   

Translations
------------------
If you want to contribute translating PDFsam to your language you can do it [here](https://translations.launchpad.net/pdfsam/pdfsam-v3)

Tips and tweaks  
------------------
A list of properties and arguments that can tweak PDFsam behavior can be found [here](https://github.com/torakiki/pdfsam/wiki/Properties-and-arguments) 

  [GNU Affero General Public License]: http://www.gnu.org/licenses/agpl-3.0.html
